推荐学习书目
› Learn Python the Hard Way
Python Sites
› PyPI - Python Package Index
› http://diveintopython.org/toc/index.html
› Pocoo
值得关注的项目
› PyPy
› Celery
› Jinja2
› Read the Docs
› gevent
› pyenv
› virtualenv
› Stackless Python
› Beautiful Soup
› 结巴中文分词
› Green Unicorn
› Sentry
› Shovel
› Pyflakes
› pytest
Python 编程
› pep8 Checker
Styles
› PEP 8
› Google Python Style Guide
› Code Style from The Hitchhiker's Guide
WaJueJiPrince
V2EX  ›  Python

Python 模拟“黑客帝国”影片中的终端动画脚本

  •  
  •   WaJueJiPrince · Aug 18, 2018 · 6319 views
    This topic created in 3000 days ago, the information mentioned may be changed or developed.

    Python 模拟“黑客帝国”影片中的终端动画脚本

    前言

    翻阅Github发现一个模拟黑客帝国终端动画的效果!只需要安装以后运行简单命令就好!效果图:

    安装

    采用 Python 包管理工具pip安装即可:

    pip install git+https://github.com/will8211/unimatrix.git
    

    运行

    安装好以后在终端运行下面命令即可:

    unimatrix -n -s 96 -l o
    
    unimatrix -c blue -u ILovePython
    
    unimatrix -c yellow -l e
    

    命令参数

    USAGE
      unimatrix [-a] [-b] [-c COLOR] [-f] [-g COLOR] [-h] [-l CHARACTER_LIST] [-n]
                [-o] [-s SPEED] [-u CUSTOM_CHARACTERS]
    
    OPTIONAL ARGUMENTS
      -a                   Asynchronous scroll. Lines will move at varied speeds.
    
      -b                   Use only bold characters
    
      -c COLOR             One of: green (default), red, blue, white, yellow, cyan,
                           magenta, black
    
      -f                   Enable "flashers," characters that continuously change.
    
      -g COLOR             Background color (See -c). Defaults to keeping
                           terminal's current background.
    
      -h                   Show this help message and exit
    
      -l CHARACTER_LIST    Select character set(s) using a string over letter
                           codes (see CHARACTER SETS below.)
    
      -n                   Do not use bold characters (overrides -b)
    
      -o                   Disable on-screen status
    
      -s SPEED             Integer up to 100. 0 uses a one-second delay before
                           refreshing, 100 uses none. Use negative numbers for
                           even lower speeds. Default=85
    
      -t TIME              Exit the process after TIME seconds
    
      -u CUSTOM_CHARACTERS Your own string of characters to display. Enclose in
                           single quotes ('') to escape special characters. For
                           example: -u '#$('
    
      -w                   Single-wave mode: Does a single burst of green rain,
                           exits. You can put in a .bashrc file to run when your
                           terminal launches. Works well with speed at 95.
    
    LONG ARGUMENTS
      -a --asynchronous
      -b --all-bold
      -c --color=COLOR
      -f --flashers
      -g --bg-color=COLOR
      -h --help
      -l --character-list=CHARACTER_LIST
      -s --speed=SPEED
      -n --no-bold
      -o --status-off
      -t --time
      -u --custom_characters=CUSTOM_CHARACTERS
      -w --single_wave
    
    CHARACTER SETS
      When using '-l' or '--character_list=' option, follow it with one or more of
      the following letters:
    
      a   Lowercase alphabet
      A   Uppercase alphabet
      c   Lowercase Russian Cyrillic alphabet
      C   Uppercase Russian Cyrillic alphabet
      e   A few common emoji ( ☺☻✌♡♥❤⚘❀❃❁✼☀✌♫♪☃❄❅❆☕☂★ )
      g   Lowercase Greek alphabet
      G   Uppercase Greek alphabet
      k   Japanese katakana (half-width)
      m   Default 'Matrix' set, equal to 'knnssss'
      n   Numbers 0-9
      o   'Old' style non-unicode set, like cmatrix. Equal to 'AaSn'
      p   Klingon pIqaD (requires 'Horta' family font)*
      P   Klingon pIqaD (requires 'Klingon-pIqaD' or 'Code2000' family font)*
      r   Lowercase Roman numerals ( mcclllxxxxvvvvviiiiii )
      R   Uppercase Roman numerals ( MCCLLLXXXXVVVVVIIIIII )
      s   A subset of symbols actually used in the Matrix films ( -=*_+|:<>" )
      S   All common keyboard symbols ( `-=~!z#$%^&*()_+[]{}|\;':",./<>?" )
      u   Custom characters selected using -u switch
    
      For example: '-l naAS' or '--character_list=naAS' will give something similar
      to the output of the original cmatrix program in its default mode.
      '-l ACG' will use all the upper-case character sets. Use the same
      letter multiple times to increase the frequency of the character set. For
      example, the default setting is equal to '-l knnssss'.
    
      * With most modern Linux terminals (gnome-terminal, konsole, lxterminal,
        xfce4-terminal, mate-terminal) simply having the font installed system-wide
        is enough. The terminal will fall back to it for the Klingon, meaning that
        you don't have to select it in your terminal settings. 'Horta' seems not to
        work in Konsole. Fonts may need to be set manually as fallbacks in
        .Xresources for older terminals, such as urxvt and xterm.
    
    KEYBOARD CONTROL
      SPACE, CTRL-c or q   exit
      - or LEFT            decrease speed by 1
      + or RIGHT           increase speed by 1
      [ or DOWN            decrease speed by 10
      ] or UP              increase speed by 10
      a                    toggle asynchronous scrolling
      b                    cycle through bold character options
                               (bold off-->bold on-->all bold)
      f                    toggle flashing characters
      o                    toggle on-screen status
      1 to 9               set color: (1) Green   (2) Red   (3) Blue     (4) White
                                      (5) Yellow  (6) Cyan  (7) Magenta  (8) Black
                                      (9) Terminal default
      ! to (               set background color (same colors as above, but pressing
                               shift + number)
    
    EXAMPLES
      Mimic default output of cmatrix (no unicode characters, works in TTY):
        $ unimatrix -n -s 96 -l o
    
      Use the letters from the name of your favorite operating system in bold blue:
        $ unimatrix -B -u Linux -c blue
    
      Use default character set, plus dollar symbol (note single quotes around
          special character):
        $ unimatrix -l knnssssu -u '$'
    
      No bold characters, slowly, using emojis, numbers and a few symbols:
        $ unimatrix -n -l ens -s 50
    

    项目链接

    UniMatrix

    14 replies  •  2018-08-20 12:43:47 +08:00
    frmongo
    frmongo
    Aug 18, 2018 via Android
    1
    酷炫
    xiiin
    xiiin
    Aug 18, 2018
    2
    很久以前用 VB6 的时候,做过类似的应用。
    但是我做的每一列都是相同的字符,采用了透明度近似实现成“虚影”的效果。
    JCZ2MkKb5S8ZX9pq
    JCZ2MkKb5S8ZX9pq
    Aug 18, 2018
    3
    前一阵试多行内容刷新的时候,顺便也写过一个。不过倒是没想到用半角日文字。
    LvMax
    LvMax
    Aug 18, 2018 via iPhone
    4
    下次朋友看我工作就给他看这个了
    likuku
    likuku
    Aug 18, 2018 via iPhone
    5
    几年前用过类似的,上班有时会完全在终端下工作,就索性全屏,临时离开就开启一个这种字幕瀑布程序
    ACool
    ACool
    Aug 18, 2018 via Android❤️1
    6
    不用这么麻烦,直接 sudo apt-get install cmatrix
    按 F11 把 terminal 全屏,输入『 cmatrix -b 』
    dobelee
    dobelee
    Aug 18, 2018 via Android
    7
    下载个源码编译,比这个炫酷。
    captainjack
    captainjack
    Aug 18, 2018
    8
    6 楼才是正解。。。
    MOmc
    MOmc
    Aug 19, 2018 via iPhone
    9
    脑阔忽然想到这个以后给来参观的领导演示
    cz5424
    cz5424
    Aug 19, 2018 via Android
    10
    收藏收藏
    NicholasWangC
    NicholasWangC
    Aug 19, 2018
    11
    wm5d8b
    wm5d8b
    Aug 19, 2018
    12
    黑客帝国中下落的究竟是什么文字?
    viho
    viho
    Aug 19, 2018
    13
    大神,您好,我是萌新,我想问问您,有接触过用 python 爬取 app 数据的么
    WaJueJiPrince
    WaJueJiPrince
    OP
    Aug 20, 2018
    14
    @viho 我抓取过今日头条等 APP,是你需要的吗?
    About   ·   Help   ·   Advertise   ·   Blog   ·   API   ·   FAQ   ·   Privacy   ·   Solana   ·   2916 Online   Highest 6679   ·     Select Language
    创意工作者们的社区
    World is powered by solitude
    VERSION: 3.9.8.5 · 56ms · UTC 12:42 · PVG 20:42 · LAX 04:42 · JFK 07:42
    ♥ Do have faith in what you're doing.